@@ -33,6 +33,9 @@ class QueryAllCustomerGrowthByYearMonth(CategoryAndCountQueryBaseResource):
         date_range_from   = kwrgs.get('date_range_from')
         date_range_to     = kwrgs.get('date_range_to')
         
+        logger.debug('QueryAllCustomerGrowthByYearMonth debug: date_range_from=%s',  date_range_from)
+        logger.debug('QueryAllCustomerGrowthByYearMonth debug: date_range_to=%s',  date_range_to)
+        
         where_condition  = ''
         
         if date_range_from and date_range_to:
