@@ -32,37 +32,40 @@ class QueryBaseResource(Resource):
         return self.get()
     
     def get(self):
-        logger.info('query base resource')
+        logger.info('query base resource from QueryBaseResource') 
+        content         = {}
+        try:
+            content         = request.args or request.args.to_dict() or request.json or {}
+        except:
+            logger.warn('failed to get content where %s', get_tracelog())
         
-        content         = request.args.to_dict() or request.json or {}
+        logger.info('content=%s', content)
         
-        logger.debug('content=%s', content)
+        #if is_not_empty(content):
+        query           = self.prepare_query(**content)
         
-        if is_not_empty(content):
-            query           = self.prepare_query(**content)
+        logger.info('query=%s', query)
+        
+        bg_client       = create_bigquery_client(credential_filepath=analytics_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH)
+        
+        if bg_client is not None:
+            logger.info('BigQuery Client is not none, thus going to execute query')
+        
+        try:
+            job_result_rows = execute_query(bg_client, query)
             
-            logger.debug('query=%s', query)
-            
-            bg_client       = create_bigquery_client(credential_filepath=analytics_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH)
-            
-            if bg_client is not None:
-                logger.debug('BigQuery Client is not none, thus going to execute query')
-            
-            try:
-                job_result_rows = execute_query(bg_client, query)
-                
-                bg_client.close()
-            except:
-                job_result_rows = []
-                logger.error('Failed to execute query due to %s', get_tracelog())
-            
-            query_result    = self.process_query_result(job_result_rows)
-            
-            logger.debug('query_result=%s', query_result)
-            
-            return query_result
-        else:
-            return {}
+            bg_client.close()
+        except:
+            job_result_rows = []
+            logger.error('Failed to execute query due to %s', get_tracelog())
+        
+        query_result    = self.process_query_result(job_result_rows)
+        
+        logger.info('query_result=%s', query_result)
+        
+        return query_result
+        #else:
+        #    return {}
         
     def prepare_query(self, **kwrgs):
         pass
