@@ -79,14 +79,14 @@ class InitImportDataBaseResource(TriggerImportDataBaseResource):
         data_payload    = self.get_data_payload() or {}
         task_url        = None
         
-        logger.debug('%s: data_payload=%s', self.__class__.name, data_payload)
+        logger.info('%s: data_payload=%s', self.__class__.__name__, data_payload)
         
         try:
             
             total_count     = self.get_import_data_count(**data_payload) or 0
             
             
-            logger.debug('%s: total_count=%s', self.__class__.name,total_count)
+            logger.debug('%s: total_count=%s', self.__class__.__name__,total_count)
             
             if total_count>0:
                 try:
@@ -116,8 +116,8 @@ class InitImportDataBaseResource(TriggerImportDataBaseResource):
                         task_url    = analytics_conf.UPSTREAM_BASE_URL + task_url
                         queue_name  = self.get_task_queue()
                         
-                        logger.debug('%s: task_url=%s', self.__class__.name, task_url)
-                        logger.debug('%s: queue_name=%s', self.__class__.name, queue_name)
+                        logger.info('%s: task_url=%s', self.__class__.__name__, task_url)
+                        logger.info('%s: queue_name=%s', self.__class__.__name__, queue_name)
                         
                         create_task(task_url, queue_name, 
                                     in_seconds      = self.get_task_delay_in_seconds(),
