@@ -82,7 +82,7 @@ class TriggerImportAllUpstreamData(TriggerImportDataBaseResource):
 class InitImportAllUpstreamData(InitImportDataBaseResource):
     def get_import_data_count(self, **kwargs):
         count =  count_all_unsend_upstream_data()
-        logger.debug('InitImportAllUpstreamData debug: unsend upstream data count = %d', count)
+        logger.info('InitImportAllUpstreamData debug: unsend upstream data count = %d', count)
         return count
     
     def get_import_data_page_size(self):
